Combino
=======
Features and usage can be found on my hompeage and the github wiki.

Quick Install (Easy_Install)
----------------------------

You can use one of the Python Package managers to install this Library.
	PyPm (From the ActivePython Distribution)
	Pip
	Easy_Install
	
Who Am I?
=========
I'm v3n0m3x a Python and Qt Programmer.